# Clang Python package for PyPI

This is the python bindings subdir of llvm clang repository.
https://github.com/llvm/llvm-project/tree/main/clang/bindings/python

The debian packages are pulled from llvm repo, extracted and pushed to pypi.

## Installation

You can install the package using pip:

```bash
pip install clang
```

Or for a specific version:

```bash
pip install clang==14
```

## License

This project is licensed under the Apache-2.0 License with LLVM exception. See the LICENSE file for more details.